from flask import Flask, render_template, request, redirect, url_for, flash
import re

app = Flask(__name__)
app.secret_key = 'your_secret_key'

# Sample data structure to store names and telephone numbers
contacts = []

# Function to validate telephone number format
def validate_phone_number(phone):
    pattern = re.compile(r'^\d{3}-\d{3}-\d{4}$')
    return bool(pattern.match(phone))

# Route to display the form to add a new contact
@app.route('/')
def index():
    return render_template('index.html', contacts=contacts)

# Route to add a new contact
@app.route('/add_contact', methods=['POST'])
def add_contact():
    name = request.form['name']
    phone = request.form['phone']

    if validate_phone_number(phone):
        contacts.append({'name': name, 'phone': phone})
        flash('Contact added successfully!', 'success')
    else:
        flash('Invalid phone number format. Please use ddd-ddd-dddd format.', 'error')

    return redirect(url_for('index'))

# Route to search for a contact
@app.route('/search', methods=['GET', 'POST'])
def search():
    query = request.form['search']
    results = [contact for contact in contacts if query.lower() in contact['name'].lower()]
    return render_template('index.html', contacts=results)

if __name__ == '__main__':
    app.run(debug=True)
